@@ -15,9 +15,6 @@ from sage.rings.polynomial.polynomial_ring_constructor import BooleanPolynomialR
 from sage.rings.polynomial.term_order import TermOrder
 from sage.rings.polynomial.multi_polynomial_element import degree_lowest_rational_function
 
-# Infinite Polynomial Rings
-from sage.rings.polynomial.infinite_polynomial_ring import InfinitePolynomialRing
-
 # Laurent Polynomial Rings
 from sage.rings.polynomial.laurent_polynomial_ring import LaurentPolynomialRing
 
